@@ -24,12 +24,14 @@
 
 extern long long __syscall_utc_time (void);
 extern long long __syscall_local_time (void);
-extern void __syscall_unpack_time (long long ticks, __native__ int tm,
-                                   _Bool is_local);
+extern void __syscall_unpack_time (long long ticks, long tm, _Bool is_local);
+extern void __syscall_sleep_ticks (long long ticks);
 
 #define	EPOCH_ADJUST        62135596800LL
 #define	TICKS_PER_SEC       10000000LL
+#define	TICKS_PER_USEC      10LL
 #define TICKS_PER_CLOCKS    10LL
+#define NSECS_PER_TICK      100LL
 
 #define	TIME_TO_TICKS(t)	(((t) + EPOCH_ADJUST) * TICKS_PER_SEC)
 
